@@ -13,7 +13,7 @@ memoize('compile_marc_path');
 memoize('parse_marc_spec');
 memoize('get_index_range');
 
-our $VERSION = '1.06';
+our $VERSION = '1.07';
 
 sub marc_map {
     my $self      = $_[0];
@@ -71,9 +71,10 @@ sub marc_map {
                     push @{ $_h->{ $field->[$i] } } , $field->[$i + 1];
                 }
                 my $subfield = $context->{subfield};
-                $subfield =~ s{^[a-zA-Z0-9]}{}g;
+                $subfield =~ s{[^a-zA-Z0-9]}{}g;
                 for my $c (split('',$subfield)) {
-                    push @$v , @{ $_h->{$c} } if exists $_h->{$c};
+                    my $val = $_h->{$c} // [undef];
+                    push @$v , @{ $val } ;
                 }
             }
             else {
@@ -87,11 +88,15 @@ sub marc_map {
 
             if (@$v) {
                 if (!$split) {
-                    $v = join $join_char, @$v;
+                    my @defined_values = grep {defined($_)} @$v;
+                    $v = join $join_char, @defined_values;
                 }
 
                 if (defined(my $off = $context->{from})) {
-                    $v = join $join_char, @$v if (ref $v eq 'ARRAY');
+                    if (ref $v eq 'ARRAY') {
+                        my @defined_values = grep {defined($_)} @$v;
+                        $v = join $join_char, @defined_values;
+                    }
                     my $len = $context->{len};
                     if (length(${v}) > $off) {
                         $v = substr($v, $off, $len);
